@@ -1,6 +1,6 @@
 # score test of nonconstant variance (J. Fox)
 
-# last modified 9 Nov 02 by J. Fox
+# last modified 30 Apr 04 by J. Fox
 
 ncv.test<-function(model, ...){
     # last modified 15 Dec 2000 by J. Fox
@@ -8,12 +8,11 @@ ncv.test<-function(model, ...){
     }
 
 ncv.test.lm<-function (model, var.formula, data=NULL, subset, na.action, ...) {
-    # last modified 13 Nov 2001 by J. Fox
-    if (!is.null(weights(model))) stop("requires unweighted linear model")
+    # last modified 30 Apr 2004 by J. Fox
     if ((!is.null(class(model$na.action))) && class(model$na.action) == 'exclude') 
         model <- update(model, na.action=na.omit)
     sumry<-summary(model)
-    residuals<-residuals(model)
+    residuals <- residuals(model, type="pearson") # suggested by S. Weisberg
     S.sq<-df.residual(model)*(sumry$sigma)^2/sum(!is.na(residuals))
     U<-(residuals^2)/S.sq
     if (missing(var.formula)) {
